{% extends "payments/base.html" %} {% block title %}Payment History{% endblock title %} {% block body %} {% include "payments/_subscription_status.html" %}

## Payment History

Your transaction history

{% if request.user.customer.invoices.all %}

Transaction ID | Date | Amount
--- | --- | ---
{% for invoice in request.user.customer.invoices.all %}
#{{ invoice.id }} | {{ invoice.date|date:"M d" }} | {% if invoice.paid and invoice.total > 0 %} Paid ${{ invoice.total|floatformat:"2" }} {% endif %} {% if invoice.paid and invoice.total < 0 %} Credit ${{ invoice.total|floatformat:"2" }} {% endif %}
{% endfor %}

{% else %}

You have not made any payments yet.

{% endif %} {% endblock %}